@@ -15,25 +15,26 @@
 # Parts of the code below is taken from:
 # http://carnivore.it/2012/10/12/python3.3_sendmsg_and_recvmsg
 #
-import sys
-
-from pysnmp import debug
-
 import ctypes
 import ipaddress
 import socket
-from pysnmp.carrier import sockfix
-from pysnmp.carrier import error
+
+from pysnmp import debug
+
 
 uint32_t = ctypes.c_uint32
 in_addr_t = uint32_t
 
 
-class in_addr(ctypes.Structure):
+class in_addr(ctypes.Structure):  # noqa: N801
+    """Represent an IPv4 address."""
+
     _fields_ = [("s_addr", in_addr_t)]
 
 
-class in6_addr_U(ctypes.Union):
+class in6_addr_U(ctypes.Union):  # noqa: N801
+    """Represent an IPv6 address."""
+
     _fields_ = [
         ("__u6_addr8", ctypes.c_uint8 * 16),
         ("__u6_addr16", ctypes.c_uint16 * 8),
@@ -41,13 +42,17 @@ class in6_addr_U(ctypes.Union):
     ]
 
 
-class in6_addr(ctypes.Structure):
+class in6_addr(ctypes.Structure):  # noqa: N801
+    """Represent an IPv6 address."""
+
     _fields_ = [
         ("__in6_u", in6_addr_U),
     ]
 
 
-class in_pktinfo(ctypes.Structure):
+class in_pktinfo(ctypes.Structure):  # noqa: N801
+    """Represent an IPv4 packet information."""
+
     _fields_ = [
         ("ipi_ifindex", ctypes.c_int),
         ("ipi_spec_dst", in_addr),
@@ -55,14 +60,21 @@ class in_pktinfo(ctypes.Structure):
     ]
 
 
-class in6_pktinfo(ctypes.Structure):
+class in6_pktinfo(ctypes.Structure):  # noqa: N801
+    """Represent an IPv6 packet information."""
+
     _fields_ = [
         ("ipi6_addr", in6_addr),
         ("ipi6_ifindex", ctypes.c_uint),
     ]
 
 
-def getRecvFrom(addressType):
+def get_recvfrom(addressType):
+    """Return a function that receives data from a socket and returns the data and the address of the sender.
+
+    The address is an instance of addressType.
+    """
+
     def recvfrom(s, sz):
         _to = None
 
@@ -81,7 +93,7 @@ def getRecvFrom(addressType):
                 _to = (str(addr), s.getsockname()[1])
                 break
 
-        debug.logger & debug.flagIO and debug.logger(
+        debug.logger & debug.FLAG_IO and debug.logger(
             "recvfrom: received %d octets from %s to %s; "
             "iov blob %r" % (len(data), _from, _to, ancdata)
         )
@@ -91,7 +103,12 @@ def getRecvFrom(addressType):
     return recvfrom
 
 
-def getSendTo(addressType):
+def get_sendto(addressType):
+    """Return a function that sends data to a socket and returns the number of bytes sent.
+
+    The address is an instance of addressType.
+    """
+
     def sendto(s, _data, _to):
         ancdata = []
         if type(_to) == addressType:
@@ -110,7 +127,7 @@ def getSendTo(addressType):
             _f.ipi6_addr = in6_addr.from_buffer_copy(addr.packed)
             ancdata = [(socket.SOL_IPV6, socket.IPV6_PKTINFO, memoryview(_f).tobytes())]
 
-        debug.logger & debug.flagIO and debug.logger(
+        debug.logger & debug.FLAG_IO and debug.logger(
             "sendto: sending %d octets to %s; address %r; "
             "iov blob %r" % (len(_data), _to, addr, ancdata)
         )
